@@ -99,15 +99,21 @@
   (cron           (ash 9 3))
   (authorization/private (ash 10 3))
   (ftp            (ash 11 3))
-  (local0         (ash 12 3))
-  (local1         (ash 13 3))
-  (local2         (ash 14 3))
-  (local3         (ash 15 3))
-  (local4         (ash 16 3))
-  (local5         (ash 17 3))
-  (local6         (ash 18 3))
-  (local7         (ash 19 3))
-  (internal/mark  (ash 20 3)))
+  ;; facilities 12-15 are reserved for system use
+  (ntp            (ash 12 3))
+  (security       (ash 13 3))
+  (console        (ash 14 3))
+  (solaris-cron   (ash 15 3))
+
+  (local0         (ash 16 3))
+  (local1         (ash 17 3))
+  (local2         (ash 18 3))
+  (local3         (ash 19 3))
+  (local4         (ash 20 3))
+  (local5         (ash 21 3))
+  (local6         (ash 22 3))
+  (local7         (ash 23 3))
+  (internal/mark  (ash 24 3)))
 
 (define %system-log-facility-mask #x03f8)
 (define %system-log-priority-mask #x0007)
@@ -133,25 +139,32 @@
 (define %default-priority (system-log-priority notice))
 (define %default-facility (system-log-facility user))
 
-(define* (parse-system-log-message line #:optional sender)
+(define %default-kernel-priority (system-log-priority notice))
+
+(define* (parse-system-log-message line #:optional sender #:key (kernel? #f))
   "Parse @var{line} and return a @code{<system-log-message>} record
-representing it."
+representing it. If @var{line} lacks syslog metadata and @var{kernel?} is true,
+ set the facility of the return value to @code{kernel}."
   (match (false-if-exception (regexp-exec %system-log-message-rx line))
     (#f
-     (system-log-message (logior %default-facility %default-priority)
+     (system-log-message (if kernel?
+                             (logior (system-log-facility kernel)
+                                     %default-kernel-priority)
+                             (logior %default-facility %default-priority))
                          line sender))
     (m
      (let* ((facility+priority (string->number (match:substring m 1))))
        (system-log-message facility+priority
                            (match:suffix m) sender)))))
 
-(define* (read-system-log-message port #:optional sender)
+(define* (read-system-log-message port #:optional sender #:key kernel?)
   "Read a system log message from @var{port}.  Return the end-of-file object
 or a <system-log-message> object, with @var{sender} (either a socket address
-or @code{#f}) as its sender."
+or @code{#f}) as its sender. If @var{kernel?} is true @var{port} represents the
+port for the kernel log."
   (match (read-line port)
     ((? eof-object? eof) eof)
-    (line (parse-system-log-message line sender))))
+    (line (parse-system-log-message line sender #:kernel? kernel?))))
 
 (define %kernel-prefix
   ;; Prefix from messages coming from the "kernel" facility.
@@ -206,10 +219,11 @@ case where BV does not contain only valid UTF-8."
       (getsockname port))
     (const #f)))
 
-(define (run-system-log channel ports dispatcher)
+(define* (run-system-log channel ports dispatcher #:key kernel-port)
   "Return the system log, getting instructions on @var{channel}, receiving
 messages to be logged on @var{ports}, a list of sockets or other file ports,
-and passing them to @var{dispatcher}."
+and passing them to @var{dispatcher}. If set to a port @var{kernel-port} is
+used to find the port for kernel log messages in @var{ports}."
   (define buffer
     (make-bytevector 1024))
 
@@ -248,8 +262,12 @@ and passing them to @var{dispatcher}."
                         (or (port-filename port) (fileno port)))
           (close-port port)
           (loop (delq port ports)))
+         (""                                     ;ignore empty lines
+          (loop ports))
          (line
-          (put-message dispatcher (parse-system-log-message line))
+          (put-message dispatcher (parse-system-log-message
+                                   line
+                                   #:kernel? (eq? kernel-port port)))
           (loop ports))))
       (('terminate reply)
        ;; Close all of PORTS.  DISPATCHER itself is registered as a logger and
@@ -516,7 +534,8 @@ users to view recent messages without opening various files."
                          (register-service-logger this-system-log dispatcher)
                          (spawn-fiber
                           (lambda ()
-                            (run-system-log channel ports dispatcher)))
+                            (run-system-log channel ports dispatcher
+                                            #:kernel-port klog)))
                          (system-log channel ports dispatcher
                                      sources (and klog kernel-log-file))))
              #:stop (lambda (system-log)
