@@ -625,6 +625,15 @@ list, to be executed as @var{user} and @var{group}, with the given
   ;; Maximum number of entries the log of timer runs.
   50)
 
+(define (infinite-or-positive-integer? obj)
+  (or (eqv? obj +inf.0)
+      (and (integer? obj)
+           (exact? obj)
+           (positive? obj))))
+
+(define (command-or-thunk? obj)
+  (or (command? obj) (procedure? obj)))
+
 (define* (make-timer-constructor event action
                                  #:key
                                  (occurrences +inf.0)
@@ -802,10 +811,11 @@ from sleep state?).")
       (timer channel event action)))
 
   (lambda ()
-    (assert (or (eqv? occurrences +inf.0)
-                (and (integer? occurrences)
-                     (exact? occurrences)
-                     (positive? occurrences))))
+    ;; Delay type checking in this thunk so errors do not prevent loading the
+    ;; rest of the configuration.
+    (check-argument-types (calendar-event? event)
+                          (command-or-thunk? action)
+                          (infinite-or-positive-integer? occurrences))
 
     ;; First check that EVENT has matching events and return #f otherwise.
     (let ((now (time-utc->date (current-time time-utc))))
