@@ -208,7 +208,7 @@ $herd unload root test
 $herd status -n 0 | grep -e "- test-2"
 
 $herd reload root "$conf"
-test "`$herd status -n 0`" == "$pristine_status"
+test "`$herd status -n 0`" = "$pristine_status"
 
 # Dynamically loading code.
 
