@@ -32,7 +32,7 @@ trap "cat $log || true;
       rm -f $socket $conf $log $service_log $service_new_file;
       test -f $pid && kill \`cat $pid\` || true; rm -f $pid" EXIT
 
-function wait_for_file
+wait_for_file ()
 {
     i=0
     while ! test -f "$1" && test $i -lt 20
