@@ -109,7 +109,7 @@ test $($herd status | grep '\+' | wc -l) -eq 2
 
 converse_with_echo_server ()
 {
-    guile -c "(use-modules (ice-9 match) (ice-9 rdelim))
+    "$GUILE" -c "(use-modules (ice-9 match) (ice-9 rdelim))
       (define IN6ADDR_LOOPBACK 1)
       (define address $1)
       (define sock (socket (sockaddr:fam address) SOCK_STREAM 0))
@@ -126,7 +126,7 @@ $herd status test-inetd | grep "Command:.*$SHELL.*echo hello"
 
 # Initiate a conversation and make sure it creates a transient service with
 # correct process information.
-guile -c "
+"$GUILE" -c "
   (define address (make-socket-address AF_INET INADDR_LOOPBACK $PORT))
   (define sock (socket (sockaddr:fam address) SOCK_STREAM 0))
   (connect sock address)
@@ -159,7 +159,7 @@ converse_with_echo_server \
   "(make-socket-address AF_INET INADDR_LOOPBACK $PORT)" \
    && false
 
-if guile -c '(socket AF_INET6 SOCK_STREAM 0)'; then
+if "$GUILE" -c '(socket AF_INET6 SOCK_STREAM 0)'; then
     # Test IPv6 support.
     $herd start test-inetd6
 
@@ -190,7 +190,7 @@ if guile -c '(socket AF_INET6 SOCK_STREAM 0)'; then
 	"(make-socket-address AF_INET INADDR_LOOPBACK $PORT)"
 
     # Note: The following test below would hang with Fibers 1.1.0, due to
-    # <https://github.com/wingo/fibers/pull/57>.
+    # <https://codeberg.org/fibers/fibers/pulls/57>.
 fi
 
 # Now test inetd on a Unix-domain socket.
@@ -210,7 +210,7 @@ converse_with_echo_server \
 
 # Check the maximum connection limit.
 $herd start test-inetd-unix
-guile -c "
+"$GUILE" -c "
   (use-modules (ice-9 rdelim) (ice-9 match))
   (define address (make-socket-address AF_UNIX \"$service_socket\"))
   (let loop ((i 10)
