@@ -57,7 +57,7 @@ rm -f "$pid"
 
 # Run the given command in a mount namespace where $log_directory is on a very
 # small tmpfs, such that we can simulate lack of disk space for logging.
-function run_short_on_disk_space
+run_short_on_disk_space ()
 {
     unshare -mrf sh -c 'mount -t tmpfs -o size=10K tmpfs "'"$log_directory"'"; '"$*"
 }
