@@ -95,4 +95,16 @@ sudo: ludo : TTY=pts/0 ; PWD=/home/ludo ; USER=root ; COMMAND=xyz"
               (system-log-message-priority message)
               (system-log-message-content message))))))
 
+(test-equal "read-system-log-message, raw kernel"
+  (list (system-log-facility kernel)
+        (system-log-priority notice)
+        "[370383.514474] usb 1-2: USB disconnect, device number 57")
+  (call-with-input-string
+      "[370383.514474] usb 1-2: USB disconnect, device number 57"
+    (lambda (port)
+      (let ((message (read-system-log-message port #:kernel? #t)))
+        (list (system-log-message-facility message)
+              (system-log-message-priority message)
+              (system-log-message-content message))))))
+
 (test-end)
