@@ -90,8 +90,8 @@ shepherd_pid="`cat $pid`"
 
 kill -0 $shepherd_pid
 
-# Did the 'make-system-destructor' start?
-until $herd start test-system-constructor | grep running; do sleep 0.3; done
+# Did the 'test-system-destructor' start?
+until $herd status test-system-constructor | grep running; do sleep 0.3; done
 grep SYSTEM-START "$log"
 $herd stop test-system-constructor
 $herd status test-system-constructor | grep stopped
